@@ -31,19 +31,19 @@
 #include "summaryWidget.h"
 
 #include <KAboutData>   //::createAboutData()
-#include <KAction>
+#include <QAction>
 #include <KActionCollection>
-#include <KLocale>
 #include <KMessageBox>  //::start()
 #include <KStandardAction>
-#include <KStatusBar>
+#include <QStatusBar>
 #include <KPluginFactory>
+#include <KLocalizedString>
 
-#include <QtCore/QFile>        //encodeName()
-#include <QtCore/QTimer>       //postInit() hack
-#include <QtCore/QByteArray>
-#include <QtCore/QDir>
-#include <QtGui/QScrollArea>
+#include <QFile>        //encodeName()
+#include <QTimer>       //postInit() hack
+#include <QByteArray>
+#include <QDir>
+#include <QScrollArea>
 
 #include <unistd.h>       //access()
 #include <iostream>
@@ -51,20 +51,6 @@
 namespace Filelight {
 
 K_PLUGIN_FACTORY(filelightPartFactory, registerPlugin<Part>();)  // produce a factory
-K_EXPORT_PLUGIN(filelightPartFactory(KAboutData(
-               "filelightpart",
-               0,
-               ki18n(APP_PRETTYNAME),
-               APP_VERSION,
-               ki18n("Displays file usage in an easy to understand way."),
-               KAboutData::License_GPL,
-               ki18n("(c) 2002-2004 Max Howell\n\
-                (c) 2008-2013 Martin T. Sandsmark"),
-               KLocalizedString(),
-               "http://utils.kde.org/projects/filelight",
-               "martin.sandsmark@kde.org").
-               setProgramIconName(QLatin1String(APP_NAME)).
-               setCatalogName(APP_NAME)))
 
 BrowserExtension::BrowserExtension(Part *parent)
         : KParts::BrowserExtension(parent)
@@ -80,8 +66,22 @@ Part::Part(QWidget *parentWidget, QObject *parent, const QList<QVariant>&)
         , m_started(false)
 {
     Config::read();
-    setComponentData(filelightPartFactory::componentData());
-    setXMLFile(QLatin1String( "filelightpartui.rc" ));
+
+    KAboutData aboutData(
+            QStringLiteral("filelightpart"),
+            i18n(APP_PRETTYNAME),
+            QStringLiteral(APP_VERSION),
+            i18n("Displays file usage in an easy to understand way."),
+            KAboutLicense::GPL,
+            i18n("(c) 2002-2004 Max Howell\n\
+                (c) 2008-2014 Martin T. Sandsmark"),
+            QString(),
+            QStringLiteral("http://utils.kde.org/projects/filelight"),
+            QStringLiteral("martin.sandsmark@kde.org"));
+    aboutData.setProgramIconName(QStringLiteral(APP_NAME));
+    setComponentData(aboutData);
+
+    setXMLFile(QStringLiteral( "filelightpartui.rc" ));
 
     QScrollArea *scrollArea = new QScrollArea(parentWidget);
     scrollArea->setWidgetResizable(true);
@@ -110,18 +110,18 @@ Part::Part(QWidget *parentWidget, QObject *parent, const QList<QVariant>&)
 
     KStandardAction::zoomIn(m_map, SLOT(zoomIn()), actionCollection());
     KStandardAction::zoomOut(m_map, SLOT(zoomOut()), actionCollection());
-    KAction *action = actionCollection()->addAction(QLatin1String("configure_filelight"));
+    QAction *action = actionCollection()->addAction(QStringLiteral("configure_filelight"));
     action->setText(i18n("Configure Filelight..."));
-    action->setIcon(KIcon(QLatin1String("configure")));
+    action->setIcon(QIcon::fromTheme(QStringLiteral("configure")));
     connect(action, SIGNAL(triggered()), this, SLOT(configFilelight()));
 
     connect(m_map, SIGNAL(created(const Folder*)), SIGNAL(completed()));
     connect(m_map, SIGNAL(created(const Folder*)), SLOT(mapChanged(const Folder*)));
-    connect(m_map, SIGNAL(activated(KUrl)), SLOT(updateURL(KUrl)));
+    connect(m_map, SIGNAL(activated(QUrl)), SLOT(updateURL(QUrl)));
 
     // TODO make better system
-    connect(m_map, SIGNAL(giveMeTreeFor(KUrl)), SLOT(updateURL(KUrl)));
-    connect(m_map, SIGNAL(giveMeTreeFor(KUrl)), SLOT(openUrl(KUrl)));
+    connect(m_map, SIGNAL(giveMeTreeFor(QUrl)), SLOT(updateURL(QUrl)));
+    connect(m_map, SIGNAL(giveMeTreeFor(QUrl)), SLOT(openUrl(QUrl)));
 
     connect(m_manager, SIGNAL(completed(Folder*)), SLOT(scanCompleted(Folder*)));
     connect(m_manager, SIGNAL(aboutToEmptyCache()), m_map, SLOT(invalidate()));
@@ -144,20 +144,19 @@ Part::postInit()
 }
 
 bool
-Part::openUrl(const KUrl &u)
+Part::openUrl(const QUrl &u)
 {
 
     //TODO everyone hates dialogs, instead render the text in big fonts on the Map
-    //TODO should have an empty KUrl until scan is confirmed successful
+    //TODO should have an empty QUrl until scan is confirmed successful
     //TODO probably should set caption to QString::null while map is unusable
 
 #define KMSG(s) KMessageBox::information(widget(), s)
 
-    KUrl uri = u;
-    uri.cleanPath(KUrl::SimplifyDirSeparators);
-    const QString path = uri.path(KUrl::AddTrailingSlash);
+    QUrl uri = u.adjusted(QUrl::NormalizePathSegments);
+    const QString path = uri.path();
     const QByteArray path8bit = QFile::encodeName(path);
-    const bool isLocal = uri.protocol() == QLatin1String( "file" );
+    const bool isLocal = uri.scheme() == QLatin1String( "file" );
 
     if (uri.isEmpty())
     {
@@ -173,7 +172,7 @@ Part::openUrl(const KUrl &u)
     }
     else if (isLocal && access(path8bit, F_OK) != 0) //stat(path, &statbuf) == 0
     {
-        KMSG(i18n("Folder not found: %1", path));
+        KMSG(i18n("Folder not found: %1").arg(path));
     }
     else if (isLocal && !QDir(path).isReadable()) //access(path8bit, R_OK | X_OK) != 0 doesn't work on win32
     {
@@ -209,11 +208,11 @@ Part::closeUrl()
 }
 
 void
-Part::updateURL(const KUrl &u)
+Part::updateURL(const QUrl &u)
 {
     //the map has changed internally, update the interface to reflect this
     emit m_ext->openUrlNotify(); //must be done first
-    emit m_ext->setLocationBarUrl(u.prettyUrl());
+    emit m_ext->setLocationBarUrl(u.toString(QUrl::PreferLocalFile));
 
     if (m_manager->running())
         m_manager->abort();
@@ -237,11 +236,11 @@ Part::configFilelight()
 }
 
 bool
-Part::start(const KUrl &url)
+Part::start(const QUrl &url)
 {
     if (!m_started) {
-        connect(m_map, SIGNAL(mouseHover(QString)), statusBar(), SLOT(message(QString)));
-        connect(m_map, SIGNAL(created(const Folder*)), statusBar(), SLOT(clear()));
+        connect(m_map, SIGNAL(mouseHover(QString)), statusBar(), SLOT(showMessage(const QString&)));
+        connect(m_map, SIGNAL(created(const Folder*)), statusBar(), SLOT(clearMessage()));
         m_started = true;
     }
 
@@ -304,7 +303,7 @@ Part::scanCompleted(Folder *tree)
 
         statusBar()->clearMessage();
 
-        setUrl(KUrl());
+        setUrl(QUrl());
     }
 }
 
@@ -328,8 +327,8 @@ Part::showSummary()
 {
     if (m_summary == 0) {
         m_summary = new SummaryWidget(widget());
-        m_summary->setObjectName(QLatin1String( "summaryWidget" ));
-        connect(m_summary, SIGNAL(activated(KUrl)), SLOT(openUrl(KUrl)));
+        m_summary->setObjectName(QStringLiteral( "summaryWidget" ));
+        connect(m_summary, SIGNAL(activated(QUrl)), SLOT(openUrl(QUrl)));
         m_summary->show();
         m_layout->addWidget(m_summary);
     }
